# Onboard Fact Sheet Owners and Collect Data
### On this page
  * [Onboard Fact Sheet Owners](https://help.sap.com/docs/leanix/ea/collect-data-from-fact-sheet-owners#onboard-fact-sheet-owners)
  * [Collect Data from Fact Sheet Owners](https://help.sap.com/docs/leanix/ea/collect-data-from-fact-sheet-owners#collect-data-from-fact-sheet-owners)
  * [Use the Onboarding Dashboard for Fact Sheet Owners](https://help.sap.com/docs/leanix/ea/collect-data-from-fact-sheet-owners#use-the-onboarding-dashboard-for-fact-sheet-owners)
  * [Use Surveys to Collect Data](https://help.sap.com/docs/leanix/ea/collect-data-from-fact-sheet-owners#use-surveys-to-collect-data)
  * [Required Attributes](https://help.sap.com/docs/leanix/ea/collect-data-from-fact-sheet-owners#required-attributes)
  * [Monitor Progress Using Metrics](https://help.sap.com/docs/leanix/ea/collect-data-from-fact-sheet-owners#monitor-progress-using-metrics)


Onboard fact sheet owners into SAP LeanIX and collect additional information from them to enrich your inventory data.
After you’ve imported your initial set of fact sheets, assigned responsible application owners, and configured data quality controls, collect additional fact sheet attributes to enrich your inventory data. For your initial application portfolio assessment, you can start with basic attributes for applications listed in [Key Attributes for Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/key-attributes-for-application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD "Application owners need to fill in the mandatory fields and approve the quality seal on their assigned fact sheets.").
